<?php

require_once "/usr/local/www/berogui/includes/fileManagement.php";
if (!isset($skip_session) && !$skip_session) {
	require_once('/usr/local/www/berogui/includes/session.php');
}

$fileManager=new fileManagement();
$fileManager->activate(true, array(), false, isset($goToUpdateMode));

?>
